# Preparing the datasets for analysis --------------------------------------

#Import both the ball and the balloriginal datasets.
#We will use only the ball dataset for analysis.
#balloriginal has Individual and Species in there. We can use those for colouring data points later on.
#ball only has our variables of interest

attach(ball)

#Load the analysis package
library(PCAmixdata)

#Ensure categorical variables are set as factors
ball$Approach.Posture <- as.factor(ball$Approach.Posture)
ball$Manipulated <- as.factor(ball$Manipulated)

#Crosscheck to make sure that setting them as factors has gone through correctly
str(ball)

#The pcamix package needs the dataset to be split into a list
#that mentions which variables are categorical and which are numeric
ball.split <- splitmix(ball)

#Each type should be assigned to a separate object. Name these objects whatever.
X1 <- ball.split$X.quanti
X2 <- ball.split$X.quali


# Running and Interpreting the basic analysis -----------------------------
res.pcamix.ball <- PCAmix(X.quanti = X1, #This specifies the quantitative variables
                          X.quali = X2, #This specifies the qualitative ones
                          rename.level = TRUE, graph = FALSE) #These are graphical parameters. Not super important.

#Once you've run the analysis, you can explore the output.
res.pcamix.ball

#The Eigenvalues tell you the proportion of variance explained by each dimension
res.pcamix.ball$eig

write.csv(res.pcarot.ball$eig, file="copypaste.csv") #For the copypasta


# Plotting the basic analysis ---------------------------------------------

#You can plot the observations on dimensions 1 and 2 (as they explain the most variance) to see how they segregate.
#Since we're interested in seeing how wolves and dogs differ,
#We can colour the observations by species.
#However, "species" isn't included in the analysis dataset to prevent biasing the algorithm
#So, we fetch the Species info from the original dataset. Ensure that both datasets are ordered exactly the same!

plot(res.pcamix.ball, #This is what we want to plot
     choice="ind", #We want to plot the individual observations in this case
     axes=c(1,2), #This specifies dimensions 1 and 2
     label=FALSE,
     coloring.ind=balloriginal$Species, #This colours data points by species. Species info is fetched from the original dataset
     posleg="topright", #This specifies the position of the legend
     main="Observations")

#Now that we know how wolves and dogs segregate on Dimensions 1 and 2,
#let's see what these dimensions are made of.

plot(res.pcamix.ball,choice="sqload", axes=c(1,2), coloring.var=T, leg=TRUE,
     posleg="topright", main="Variable Loadings")

#This plot tells us that Manipulation Likelihood, Persistence and Diversity load highly on Dim 1
#And that Latency and posture load highly on Dim 2

plot(res.pcamix.ball,choice="cor", axes=c(1,2), main="Numerical variable Loadings")

#This plot shows us ONLY the numeric variables
#Persistence and MD seem to be positively correlated, but seem to not have a strong correlation with Latency.

plot(res.pcamix.ball,choice="levels",xlim=c(-2,4), ylim=c(-2,4), axes=c(1,2), main="Categorical Variable Loadings")

#This plot does something similar for categorical variables.
#It shows that animals that manipulated are on the right, while those that didn't are on the left.
#Similarly, insecure animals are at the bottom and confident ones on the top; but this segregation isn't strong.

#Each of these characteristics can be visualised individually by changing the colouring parameter.
plot(res.pcamix.ball, choice="ind", axes=c(1,2),label=FALSE,
     coloring.ind=X2$Approach.Posture, posleg="topright",
     main="Observations (Coloured by Approach Posture)")

plot(res.pcamix.ball, choice="ind", axes=c(1,2),label=FALSE,
     coloring.ind=X2$Manipulated, posleg="topright",
     main="Observations (Coloured by Manipulation Likelihood)")

#Since ww have all of the information for our observations, we can combine the three colourings into one plot.
#We can colour points by species and use elipses to show manipulation likelihood and approach posture.
#However, R is a P.I.T.A. when it comes to graphics. Export these graphs as PDFs and do this in Illustrator/Inkscape!

# Further exploring the basic analysis ------------------------------------

plot(res.pcamix.ball, choice="ind", axes=c(1,3),label=FALSE,
     coloring.ind=ballwithspecies$Species, posleg="topright",
     main="Observations")

plot(res.pcamix.ball,choice="sqload", axes=c(1,3), coloring.var=T, leg=TRUE,
     posleg="topright", main="Variable Loadings")

plot(res.pcamix.ball,choice="cor", axes=c(1,3), main="Numerical variable Loadings")

#Based on these plots, we see that Dimension 3 is also interesting to explore.
#The segregation pattern is different and observations cluster a bit differently.
#In some cases, this may make interpretation a lot easier

# Rotating dimensions to ease interpretations -----------------------------

#From the previous variable loading plots, we notice that Persistence and MD
#Always loaded on both Dim 1 and Dim 2 or 3. 
#If we rotate our dimensions such that these variables load ONLY on one dimension
#It makes interpretation of our plots a LOT more convenient.

#The important part is that our first three dimensions explain 83% of the variance in our data
#So these are the three dimensions we care most about and should rotate.
res.pcarot.ball<-PCArot(res.pcamix.ball,dim=3,graph=FALSE)

res.pcarot.ball$eig #We can then see the Eigenvalues of the rotated dimensions
res.pcamix.ball$eig #They are a little different from the original Eigenvalues

sum(res.pcarot.ball$eig[,2]) #But still explain the SAME amount of variance

#This "Orthogonal Rotation" process not only changes the dimensions' orientation
#It also attempts to pull loadings to their extremes. So, values close to 1 will be maximised
#And those close to 0 will be minimised
#This usually helps better understand which variables the dimensions are composed of

res.pcamix.ball$sqload[,1:5] #These are our original loadings
res.pcarot.ball$sqload #And these are the rotated ones

#We see that the values around Dim 1 and Dim 3 have improved quite a bit
#So we should ideally use these two dimensions for our visualisations.
#For the sake of completeness, you can always check the other dimensions, but you may end up with a ton of plots.

#See how the resolution of data points has changed after rotation

plot(res.pcamix.ball, choice="ind", coloring.ind=balloriginal$Species, posleg="topright", 
     axes=c(1,3), label=FALSE, main="Observations before rotation")
plot(res.pcarot.ball, choice="ind", coloring.ind=balloriginal$Species, posleg="topright", 
     axes=c(1,3), label=FALSE, main="Observations after rotation")

plot(res.pcamix.ball, choice="ind",xlim=c(-2,4), ylim=c(-2,4), coloring.ind=X2$App, posleg="topright", 
     axes=c(1,3), label=FALSE, main="Observations before rotation (by Posture)")
plot(res.pcarot.ball, choice="ind",xlim=c(-2,4), ylim=c(-2,4), coloring.ind=X2$App, posleg="topright", 
     axes=c(1,3), label=FALSE, main="Observations after rotation (by Posture)")

plot(res.pcamix.ball, choice="ind",xlim=c(-2,4), ylim=c(-2,4), coloring.ind=X2$Manipulated, posleg="topright", 
     axes=c(1,3), label=FALSE, main="Observations before rotation (by Manipulation Likelihood)")
plot(res.pcarot.ball, choice="ind",xlim=c(-2,4), ylim=c(-2,4), coloring.ind=X2$Manipulated, posleg="topright", 
     axes=c(1,2), label=FALSE, main="Observations after rotation (by Manipulation Likelihood)")

#All these plots can be combined to represent all the information in your dataset.
#I'm certain this can be done in R but I am even more certain that it is infinitely easier to do in Illustrator/Inkscape.

#This is what our variable loadings look like
plot(res.pcamix.ball,choice="sqload", axes=c(1,3), coloring.var=T, leg=TRUE,
     posleg="topright", main="Variables before Rotation")
plot(res.pcarot.ball,choice="sqload", axes=c(1,2), coloring.var=T, leg=TRUE,
     posleg="topright", main="Variables after Rotation")
#Rotating the dimensions has made our dimensions MUCH more interpretable

#For instance, before rotation, all our numerical variables contributed to dimensions 1 AND 3
plot(res.pcamix.ball,choice="cor", axes=c(1,3), main="Numerical variables before Rotation")

#Now, seperation along Dimension 1 is primarily due to persistence and diversity
#And seperation along Dimension 3 is due to contact latency
plot(res.pcarot.ball,choice="cor", axes=c(1,3), main="Numerical variables after Rotation")

#We have a similar result for our categorical variables, albeit to a slightly lesser extent.
plot(res.pcamix.ball,choice="levels",xlim=c(-2,4), ylim=c(-2,4), axes=c(1,3), main="Levels before Rotation")
plot(res.pcarot.ball,choice="levels",xlim=c(-2,4), ylim=c(-2,4), axes=c(1,3), main="Levels after Rotation")


# Overall Interpretations -------------------------------------------------

#It looks like dogs and wolves indeed behave differently in this task
#The two main variables that are responsible for the difference are persistence & motor diversity
#Individuals that did not engage in the task were ONLY dogs
#some dogs and some wolves were insecure, but this doesn't seem to affect seggregation

#Species differences in persistence and diversity are worth investigating via models
#Persistence and diversity may be connected, this may be worth investigating via models
#Contact latency and posture loaded on the same dimension. They may be conneccted and this may be worth investigating via models.
#Contact latency may not be connected to persistence & diversity.