# Preparation -------------------------------------------------------------

##Load the required packages and read data in
library(gamlss)
library(readr)
asdf <- read_csv("asdf.csv")

#Ensure that your fixed factors are set as factors in the dataset
{
  asdf$Species <- as.factor(asdf$Species)
  asdf$Object <- as.factor(asdf$Object)
  asdf$Manipulated <- as.factor(asdf$Manipulated)
  asdf$Approach.Posture <- as.factor(asdf$Approach.Posture)
}

#And then check the structures just to make sure
str(asdf)

# Main Data Distribution Checks -------------------------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is positive, continuous, use "realplus" as the type.

Persistence.Distribution <- fitDist(asdf$Persistence, type = "realplus")

#Have a look at what the AIC values for all the distributions that worked are.
Persistence.Distribution$fit

write.csv(Persistence.Distribution$fit, file="copypaste.csv") #For the copypasta

#Now let's look at what the distributions and fits look like
#If certain distributions aren't appropriate for, or do not fit the data at all, the function will throw an error
#These distributions shouldn't be used for modelling
{
histDist(asdf$Persistence, "BCPEo", density = TRUE) #Fail
histDist(asdf$Persistence, "GG", density = TRUE)  #Fail
histDist(asdf$Persistence, "GB2", density = TRUE)  #Fail
histDist(asdf$Persistence, "GIG", density = TRUE)  #Fail
histDist(asdf$Persistence, "IGAMMA", density = TRUE) #Fail

histDist(asdf$Persistence, "GA", density = TRUE)
histDist(asdf$Persistence, "BCCGo", density = TRUE)
histDist(asdf$Persistence, "BCTo", density = TRUE)
histDist(asdf$Persistence, "WEI2", density = TRUE)
histDist(asdf$Persistence, "WEI", density = TRUE)
histDist(asdf$Persistence, "WEI3", density = TRUE)
histDist(asdf$Persistence, "LOGNO2", density = TRUE)
histDist(asdf$Persistence, "LOGNO", density = TRUE)
}
# Main model distribution selection & validation --------------------------
#Stage 1: Building models & checking AICs
{
#Let's change the maximum number of model iterations so we don't run into convergence errors.
con = gamlss.control(n.cyc = 1000)

#Let's try running the model we want with the distributions that might work and compare

Persistence.GA <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                         family = "GA", data = na.omit(asdf), control = con)

Persistence.BCCGo <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                            family = "BCCGo", data = na.omit(asdf), control = con)

Persistence.BCTo <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                           family = "BCTo", data = na.omit(asdf), control = con)

Persistence.WEI2 <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                           family = "WEI2", data = na.omit(asdf), control = con)

Persistence.WEI3 <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                           family = "WEI3", data = na.omit(asdf), control = con)

Persistence.WEI <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                          family = "WEI", data = na.omit(asdf), control = con)

Persistence.LOGNO2 <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                             Family = "LOGNO2", data = na.omit(asdf), control = con)

Persistence.LOGNO <- gamlss(Persistence ~ Species*Object + Age, random = ~1|Individual,
                             Family = "LOGNO", data = na.omit(asdf), control = con)

#Check the AIC values of all the models to determine how they compare.
AIC(Persistence.GA, Persistence.BCCGo, Persistence.BCTo, Persistence.WEI2, Persistence.WEI3, Persistence.WEI, Persistence.LOGNO2, Persistence.LOGNO)

#For the copypasta
write.csv(AIC(Persistence.GA, Persistence.BCCGo, Persistence.BCTo, Persistence.WEI2, Persistence.WEI3, Persistence.WEI, Persistence.LOGNO2, Persistence.LOGNO), file="copypaste.csv")

}
#Stage 2: Diagnostics via Plots
{
##QQ Plots:
#The Normal QQ plot should ideally have points very close to the line.
#Residuals against index should be completely random with no visible patterns.
plot(Persistence.GA)
plot(Persistence.BCTo)
plot(Persistence.WEI)
plot(Persistence.WEI3)
plot(Persistence.WEI2)
plot(Persistence.LOGNO2)
plot(Persistence.LOGNO)

##Detrended QQ plots (aka Worm Plots)
#All residuals should be within the confidence intervals.
#Choose models that have most, if not all, points within the two dotted curves.
wp(resid=resid(Persistence.GA))
wp(resid=resid(Persistence.BCTo))
wp(resid=resid(Persistence.WEI))
wp(resid=resid(Persistence.WEI3))
wp(resid=resid(Persistence.WEI2))
wp(resid=resid(Persistence.LOGNO2))
wp(resid=resid(Persistence.LOGNO))

}
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
summary(Persistence.GA)
summary(Persistence.BCTo)
summary(Persistence.WEI)
summary(Persistence.LOGNO)
}
# Model Reduction & Validation --------------------------------------------

#Reduction of GA Model
{
  #The interaction isn't significant. Before dropping terms, check how this affects the AIC
  dropterm(Persistence.GA, test = "Chisq")
  
  Persistence.GA.2 <- gamlss(Persistence ~ Species + Object + Age, random = ~1|Individual,
                             family = "GA", data = na.omit(asdf), control = con) 
  summary(Persistence.GA.2)
}

#Reduction of the BCTo Model
{
dropterm(Persistence.BCTo, test = "Chisq")

Persistence.BCTo.2 <- gamlss(Persistence ~ Species + Object + Age, random = ~1|Individual,
                           family = "BCTo", data = na.omit(asdf), control = con) 
summary(Persistence.BCTo.2)
}

#Reduction of WEI Model
{
  #The interaction isn't significant. Before dropping terms, check how this affects the AIC
  dropterm(Persistence.WEI, test = "Chisq")
  
  Persistence.WEI.2 <- gamlss(Persistence ~ Species + Object + Age, random = ~1|Individual,
                             family = "WEI", data = na.omit(asdf), control = con) 
  summary(Persistence.WEI.2)
}

#Reduction of LOGNO Model
{
  #The interaction isn't significant. Before dropping terms, check how this affects the AIC
  dropterm(Persistence.LOGNO, test = "Chisq")
  
  Persistence.LOGNO.2 <- gamlss(Persistence ~ Species + Object + Age, random = ~1|Individual,
                              family = "LOGNO", data = na.omit(asdf), control = con) 
  summary(Persistence.LOGNO.2)
}

AIC(Persistence.GA, Persistence.GA.2,
    Persistence.BCTo, Persistence.BCTo.2,
    Persistence.WEI, Persistence.WEI.2,
    Persistence.LOGNO, Persistence.LOGNO.2)

write.csv(AIC(Persistence.GA, Persistence.GA.2,
              Persistence.BCTo, Persistence.BCTo.2,
              Persistence.WEI, Persistence.WEI.2,
              Persistence.LOGNO, Persistence.LOGNO.2),
          file="copypaste.csv") #For the copypasta