# Preparation -------------------------------------------------------------

##Load the required packages and read data in
library(gamlss)
library(readr)
dogs <- read_csv("dogs.csv")

#Ensure that your fixed factors are set as factors in the dataset
{
  dogs$Object <- as.factor(dogs$Object)
  dogs$Manipulated <- as.factor(dogs$Manipulated)
  dogs$Approach.Posture <- as.factor(dogs$Approach.Posture)
}

#And then check the structures just to make sure
str(dogs)



# Main Distribution Checks ------------------------------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is positive, continuous, use "realplus" as the type.

DogsLatency.Distribution <- fitDist(dogs$Contact.Latency, type = "realplus")

#Have a look at what the AIC values for all the distributions that worked are.
DogsLatency.Distribution$fit

write.csv(DogsLatency.Distribution$fit, file="copypaste.csv") #For the copypasta

#Now let's look at what the distributions and fits look like
{
histDist(Contact.Latency, "IGAMMA", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "exGAUS", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "GG", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "IG", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "BCCGo", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "BCCG", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "LOGNO2", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "LOGNO", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "GIG", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "GB2", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "BCT", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "BCTo", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "GA", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "WEI3", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "WEI2", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "WEI", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
histDist(Contact.Latency, "EXP", density = TRUE, data = na.omit(dogs), ylim = c(0,1.5))
}


# Main model distribution selection & validation --------------------------
#Stage 1: Building models & checking AICs
{
#Let's change the maximum number of model iterations so we don't run into convergence errors.
con = gamlss.control(n.cyc = 1000)
  
#Let's try running the model we want with the distributions that might work and compare them.
 
Latency.Dogs.IGAMMA <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                 random = ~1|Individual, family = "IGAMMA", data = na.omit(dogs), control = con)

Latency.Dogs.exGAUS <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "exGAUS", data = na.omit(dogs), control = con) #Fail

Latency.Dogs.GG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                             random = ~1|Individual, family = "GG", data = na.omit(dogs), control = con)

Latency.Dogs.IG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "IG", data = na.omit(dogs), control = con)

Latency.Dogs.BCCGo <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "BCCGo", data = na.omit(dogs), control = con)

Latency.Dogs.BCCG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                             random = ~1|Individual, family = "BCCG", data = na.omit(dogs), control = con)

Latency.Dogs.LOGNO <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "LOGNO", data = na.omit(dogs), control = con)

Latency.Dogs.GIG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "GIG", data = na.omit(dogs), control = con)

Latency.Dogs.BCT <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                           random = ~1|Individual, family = "BCT", data = na.omit(dogs), control = con)

Latency.Dogs.GA <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                           random = ~1|Individual, family = "GA", data = na.omit(dogs), control = con)
}
AICs <- AIC(Latency.Dogs.IGAMMA, Latency.Dogs.GG, Latency.Dogs.IG, Latency.Dogs.BCCGo, Latency.Dogs.BCCG, 
    Latency.Dogs.LOGNO, Latency.Dogs.GIG, Latency.Dogs.BCT, Latency.Dogs.GA)
write.csv(AICs, file="copypaste.csv") #For the copypasta

#Stage 2: Diagnostics via Plots
{
plot(Latency.Dogs.IG)
wp(resid=resid(Latency.Dogs.IG))

plot(Latency.Dogs.IGAMMA)
wp(resid=resid(Latency.Dogs.IGAMMA))

plot(Latency.Dogs.LOGNO)
wp(resid=resid(Latency.Dogs.LOGNO))

plot(Latency.Dogs.GA)
wp(resid=resid(Latency.Dogs.GA))

plot(Latency.Dogs.GG)
wp(resid=resid(Latency.Dogs.GG))

plot(Latency.Dogs.BCCGo)
wp(resid=resid(Latency.Dogs.BCCGo))

plot(Latency.Dogs.GIG)
wp(resid=resid(Latency.Dogs.GIG))

plot(Latency.Dogs.BCCG)
wp(resid=resid(Latency.Dogs.BCCG))

plot(Latency.Dogs.BCT)
wp(resid=resid(Latency.Dogs.BCT))
}
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
summary(Latency.Dogs.IG)
summary(Latency.Dogs.IGAMMA)
summary(Latency.Dogs.LOGNO)
summary(Latency.Dogs.GA)
summary(Latency.Dogs.GG)
summary(Latency.Dogs.BCCGo)
summary(Latency.Dogs.GIG)
summary(Latency.Dogs.BCCG)
summary(Latency.Dogs.BCT)
}

# Model Reduction & Validation --------------------------------------------

#Reduction of IG Model
{
summary(Latency.Dogs.IG)
dropterm(Latency.Dogs.IG, test = "Chisq")

Latency.Dogs.IG.2 <- gamlss(Contact.Latency ~ Object*Persistence + Age + Approach.Posture,
                               random = ~1|Individual, family = "IG", data = na.omit(dogs), control = con)
summary(Latency.Dogs.IG.2)
dropterm(Latency.Dogs.IG.2, test = "Chisq")

Latency.Dogs.IG.3 <- gamlss(Contact.Latency ~ Object + Persistence + Age + Approach.Posture,
                               random = ~1|Individual, family = "IG", data = na.omit(dogs), control = con)

summary(Latency.Dogs.IG.3)
}

#Reduction of IGAMMA Model
{
  summary(Latency.Dogs.IGAMMA)
  dropterm(Latency.Dogs.IGAMMA, test = "Chisq")
  
  Latency.Dogs.IGAMMA.2 <- gamlss(Contact.Latency ~ Object*Persistence + Age + Approach.Posture,
                              random = ~1|Individual, family = "IGAMMA", data = na.omit(dogs), control = con)
  summary(Latency.Dogs.IGAMMA.2)
  dropterm(Latency.Dogs.IGAMMA.2, test = "Chisq")
  
  Latency.Dogs.IGAMMA.3 <- gamlss(Contact.Latency ~ Object + Persistence + Age + Approach.Posture,
                              random = ~1|Individual, family = "IGAMMA", data = na.omit(dogs), control = con)
  
  summary(Latency.Dogs.IGAMMA.3)
}

#Reduction of LOGNO Model
{
  summary(Latency.Dogs.LOGNO)
  dropterm(Latency.Dogs.LOGNO, test = "Chisq")
  
  Latency.Dogs.LOGNO.2 <- gamlss(Contact.Latency ~ Object*Persistence + Age + Approach.Posture,
                                  random = ~1|Individual, family = "LOGNO", data = na.omit(dogs), control = con)
  summary(Latency.Dogs.LOGNO.2)
  dropterm(Latency.Dogs.LOGNO.2, test = "Chisq")
  
  Latency.Dogs.LOGNO.3 <- gamlss(Contact.Latency ~ Object + Persistence + Age + Approach.Posture,
                                  random = ~1|Individual, family = "LOGNO", data = na.omit(dogs), control = con)
  
  summary(Latency.Dogs.LOGNO.3)
}

#Reduction of GA Model
{
  summary(Latency.Dogs.GA)
  dropterm(Latency.Dogs.GA, test = "Chisq")
  
  Latency.Dogs.GA.2 <- gamlss(Contact.Latency ~ Object*Persistence + Age + Approach.Posture,
                                 random = ~1|Individual, family = "GA", data = na.omit(dogs), control = con)
  summary(Latency.Dogs.GA.2)
  dropterm(Latency.Dogs.GA.2, test = "Chisq")
  
  Latency.Dogs.GA.3 <- gamlss(Contact.Latency ~ Object + Persistence + Age + Approach.Posture,
                                 random = ~1|Individual, family = "GA", data = na.omit(dogs), control = con)
  
  summary(Latency.Dogs.GA.3)
}

AICs <- AIC(Latency.Dogs.IG, Latency.Dogs.IG.2, Latency.Dogs.IG.3)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Latency.Dogs.IGAMMA, Latency.Dogs.IGAMMA.2, Latency.Dogs.IGAMMA.3)
write.csv(AICs, file="copypaste.csv", append = TRUE)

AICs <- AIC(Latency.Dogs.LOGNO, Latency.Dogs.LOGNO.2, Latency.Dogs.LOGNO.3)
write.csv(AICs, file="copypaste.csv", append = TRUE)

AICs <- AIC(Latency.Dogs.GA, Latency.Dogs.GA.2, Latency.Dogs.GA.3)
write.csv(AICs, file="copypaste.csv", append = TRUE)


# Plots -------------------------------------------------------------------

#Setting up the plot area
par(mar = c(3.5,3.5,2,0.15), #Defining the inner margins (Bottom, Left, Top, Right)
    oma = c(0.2,0.2,0,0), #Setting outer margins (same order as above)
    mgp = c (2.25,1,0), #Setting distance of labels from axis
    bg = NA) #Setting background colour to transparent

plot(Contact.Latency ~ Persistence, data = dogs,
     main = "Contact Latency vs. Persistence (Dogs)",
     xlab="Persistence (sec)", ylab="Contact Latency (sec)")

#Adding a red coloured trend line
abline(lm(Contact.Latency ~ Persistence, 
          data = dogs), col="red")

plot(Contact.Latency ~ Age, data = dogs,
     main = "Contact Latency vs. Age (Dogs)",
     xlab="Age (years)", ylab="Contact Latency (sec)")

#Adding a red coloured trend line
abline(lm(Contact.Latency ~ Age, 
          data = dogs), col="red")