# Preparation -------------------------------------------------------------

##Load the required packages and read data in
library(gamlss)
library(readr)
wolves <- read_csv("wolves.csv")

#Ensure that your fixed factors are set as factors in the dataset
{
  wolves$Object <- as.factor(wolves$Object)
  wolves$Manipulated <- as.factor(wolves$Manipulated)
  wolves$Approach.Posture <- as.factor(wolves$Approach.Posture)
}

#And then check the structures just to make sure
str(wolves)


# Main Distribution Checks ------------------------------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is positive, continuous, use "realplus" as the type.

Wolves.Latency.Distribution <- fitDist(wolves$Contact.Latency, type = "realplus")

#Have a look at what the AIC values for all the distributions that worked are.
Wolves.Latency.Distribution$fit

write.csv(Wolves.Latency.Distribution$fit, file="copypaste.csv") #For the copypasta

#Now let's look at what the distributions and fits look like
{
histDist(Contact.Latency, "BCPEo", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "BCPE", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "GA", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "WEI", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "WEI3", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "WEI2", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "LOGNO2", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "LOGNO", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "exGAUS", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "BCCGo", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "BCCG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "GG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "GIG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "IG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "GB2", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "BCT", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "BCTo", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "IGAMMA", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
histDist(Contact.Latency, "EXP", density = TRUE, data = na.omit(wolves), ylim = c(0,0.8))
}



# Main model distribution selection & validation --------------------------
#Stage 1: Building models & checking AICs
{
#Let's change the maximum number of model iterations so we don't run into convergence errors.
con = gamlss.control(n.cyc = 1000)
  
#Let's try running the model we want with the distributions that might work and compare them.
 
Latency.Wolves.BCPEo <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                 random = ~1|Individual, family = "BCPEo", data = na.omit(wolves), control = con)

Latency.Wolves.GA <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                            random = ~1|Individual, family = "GA", data = na.omit(wolves), control = con)

Latency.Wolves.WEI <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                            random = ~1|Individual, family = "WEI", data = na.omit(wolves), control = con)

Latency.Wolves.LOGNO <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                               random = ~1|Individual, family = "LOGNO", data = na.omit(wolves), control = con)

Latency.Wolves.exGAUS <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "exGAUS", data = na.omit(wolves), control = con) #Fail

Latency.Wolves.BCCGo <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                         random = ~1|Individual, family = "BCCGo", data = na.omit(wolves), control = con)

Latency.Wolves.BCCG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                             random = ~1|Individual, family = "BCCG", data = na.omit(wolves), control = con)

Latency.Wolves.GG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                            random = ~1|Individual, family = "GG", data = na.omit(wolves), control = con) #Fail

Latency.Wolves.GIG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                             random = ~1|Individual, family = "GIG", data = na.omit(wolves), control = con)

Latency.Wolves.IG <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                            random = ~1|Individual, family = "IG", data = na.omit(wolves), control = con)

Latency.Wolves.BCT <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                           random = ~1|Individual, family = "BCT", data = na.omit(wolves), control = con)

Latency.Wolves.BCTo <- gamlss(Contact.Latency ~ Object*Approach.Posture + Object*Persistence + Age,
                             random = ~1|Individual, family = "BCTo", data = na.omit(wolves), control = con)
}
AICs <- AIC(Latency.Wolves.BCPEo, Latency.Wolves.GA, Latency.Wolves.WEI, Latency.Wolves.LOGNO, Latency.Wolves.BCCGo, 
            Latency.Wolves.BCCG, Latency.Wolves.GIG, Latency.Wolves.IG, Latency.Wolves.BCT, Latency.Wolves.BCTo)
write.csv(AICs, file="copypaste.csv") #For the copypasta

#Stage 2: Diagnostics via Plots
{
plot(Latency.Wolves.BCPEo)
wp(resid=resid(Latency.Wolves.BCPEo))

plot(Latency.Wolves.LOGNO)
wp(resid=resid(Latency.Wolves.LOGNO))

plot(Latency.Wolves.GA)
wp(resid=resid(Latency.Wolves.GA))

plot(Latency.Wolves.WEI)
wp(resid=resid(Latency.Wolves.WEI))

plot(Latency.Wolves.BCCG)
wp(resid=resid(Latency.Wolves.BCCG))

plot(Latency.Wolves.GIG)
wp(resid=resid(Latency.Wolves.GIG))

plot(Latency.Wolves.BCCGo)
wp(resid=resid(Latency.Wolves.BCCGo))

plot(Latency.Wolves.BCT)
wp(resid=resid(Latency.Wolves.BCT))

plot(Latency.Wolves.BCTo)
wp(resid=resid(Latency.Wolves.BCTo))

plot(Latency.Wolves.IG)
wp(resid=resid(Latency.Wolves.IG))
}
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
summary(Latency.Wolves.LOGNO)
summary(Latency.Wolves.GA)  
summary(Latency.Wolves.WEI)
summary(Latency.Wolves.BCCG)
summary(Latency.Wolves.GIG)
summary(Latency.Wolves.BCCGo)
summary(Latency.Wolves.BCT)
summary(Latency.Wolves.BCTo)
summary(Latency.Wolves.IG)
}



# Model Reduction & Validation --------------------------------------------

#Reduction of LOGNO Model
{
  summary(Latency.Wolves.LOGNO)
  dropterm(Latency.Wolves.LOGNO, test = "Chisq")
  
  Latency.Wolves.LOGNO.2 <- gamlss(Contact.Latency ~ Object * Persistence + Approach.Posture + Age,
                                random = ~1|Individual, family = "LOGNO", data = na.omit(wolves), control = con)
  summary(Latency.Wolves.LOGNO.2)
  dropterm(Latency.Wolves.LOGNO.2, test = "Chisq")
  
  Latency.Wolves.LOGNO.3 <- gamlss(Contact.Latency ~ Persistence + Object + Approach.Posture + Age,
                                random = ~1|Individual, family = "LOGNO", data = na.omit(wolves), control = con)
  
  summary(Latency.Wolves.LOGNO.3)
}

#Reduction of GA Model
{
  summary(Latency.Wolves.GA)
  dropterm(Latency.Wolves.GA, test = "Chisq")
  
  Latency.Wolves.GA.2 <- gamlss(Contact.Latency ~ Object * Persistence + Approach.Posture + Age,
                                   random = ~1|Individual, family = "GA", data = na.omit(wolves), control = con)
  summary(Latency.Wolves.GA.2)
  dropterm(Latency.Wolves.GA.2, test = "Chisq")
  
  Latency.Wolves.GA.3 <- gamlss(Contact.Latency ~ Persistence + Object + Approach.Posture + Age,
                                   random = ~1|Individual, family = "GA", data = na.omit(wolves), control = con)
  
  summary(Latency.Wolves.GA.3)
}

#Reduction of WEI Model
{
  summary(Latency.Wolves.WEI)
  dropterm(Latency.Wolves.WEI, test = "Chisq")
  
  Latency.Wolves.WEI.2 <- gamlss(Contact.Latency ~ Object * Persistence + Approach.Posture + Age,
                                random = ~1|Individual, family = "WEI", data = na.omit(wolves), control = con)
  summary(Latency.Wolves.WEI.2)
  dropterm(Latency.Wolves.WEI.2, test = "Chisq")
  
  Latency.Wolves.WEI.3 <- gamlss(Contact.Latency ~ Persistence + Object + Approach.Posture + Age,
                                random = ~1|Individual, family = "WEI", data = na.omit(wolves), control = con)
  
  summary(Latency.Wolves.WEI.3)
}

#Reduction of GIG Model
{
  summary(Latency.Wolves.GIG)
  dropterm(Latency.Wolves.GIG, test = "Chisq")
  
  Latency.Wolves.GIG.2 <- gamlss(Contact.Latency ~ Object * Persistence + Approach.Posture + Age,
                                  random = ~1|Individual, family = "GIG", data = na.omit(wolves), control = con)
  summary(Latency.Wolves.GIG.2)
  dropterm(Latency.Wolves.GIG.2, test = "Chisq")
  
  Latency.Wolves.GIG.3 <- gamlss(Contact.Latency ~ Persistence + Object + Approach.Posture + Age,
                                  random = ~1|Individual, family = "GIG", data = na.omit(wolves), control = con)
  
  summary(Latency.Wolves.GIG.3)
}

AICs <- AIC(Latency.Wolves.GA, Latency.Wolves.GA.2, Latency.Wolves.GA.3)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Latency.Wolves.LOGNO, Latency.Wolves.LOGNO.2, Latency.Wolves.LOGNO.3)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Latency.Wolves.WEI, Latency.Wolves.WEI.2, Latency.Wolves.WEI.3)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Latency.Wolves.GIG, Latency.Wolves.GIG.2, Latency.Wolves.GIG.3)
write.csv(AICs, file="copypaste.csv")


# Plots -------------------------------------------------------------------

#Setting up the plot area
par(mar = c(3.5,3.5,2,0.15), #Defining the inner margins (Bottom, Left, Top, Right)
    oma = c(0.2,0.2,0,0), #Setting outer margins (same order as above)
    mgp = c (2.25,1,0), #Setting distance of labels from axis
    bg = NA) #Setting background colour to transparent

plot(Contact.Latency ~ Persistence, data = wolves,
     main = "Contact Latency vs. Persistence (Wolves)",
     xlab="Persistence (sec)", ylab="Contact Latency (sec)")

#Adding a red coloured trend line
abline(lm(Contact.Latency ~ Persistence, 
          data = wolves), col="red")