# Preparation -------------------------------------------------------------

##Load the required packages and read data in
library(gamlss)
library(readr)
dogs <- read_csv("dogs.csv")

#Ensure that your fixed factors are set as factors in the dataset
{
  dogs$Object <- as.factor(dogs$Object)
  dogs$Manipulated <- as.factor(dogs$Manipulated)
  dogs$Approach.Posture <- as.factor(dogs$Approach.Posture)
}

#And then check the structures just to make sure
str(dogs)

# Main Distribution Checks ------------------------------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is discrete, use "counts" as the type.

Dogs.Diversity.Distribution <- fitDist(dogs$Motor.Diversity, type = "counts")

#Have a look at what the AIC values for all the distributions that worked are.
Dogs.Diversity.Distribution$fits

write.csv(Dogs.Diversity.Distribution$fits, file="copypaste.csv") #For the copypasta

#Now let's look at what the distributions and fits look like
{
  histDist(Motor.Diversity, "GEOM", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "GEOMo", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "DPO", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "NBI", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "NBII", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "GPO", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZAPIG", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZIPIG", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZINBI", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZANBI", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "WARING", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZIP", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZAP", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "PIG", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "NBF", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "DEL", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
  histDist(Motor.Diversity, "SICHEL", density = TRUE, data = na.omit(dogs), ylim = c(0,0.3))
}

# Main model distribution selection & validation --------------------------
#Stage 1: Building models & checking AICs
{
  #Let's change the maximum number of model iterations so we don't run into convergence errors.
  con = gamlss.control(n.cyc = 1000)
  
  #Let's try running the model we want with the distributions that might work and compare.
  
  Diversity.Dogs.GEOM <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                random = ~1|Individual, family = "GEOM", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.GEOMo <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                random = ~1|Individual, family = "GEOMo", data = na.omit(dogs), control = con) #Fail
  
  Diversity.Dogs.DPO <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                            random = ~1|Individual, family = "DPO", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.NBI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                            random = ~1|Individual, family = "NBI", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.GPO <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "GPO", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.ZAPIG <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                              random = ~1|Individual, family = "ZAPIG", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.ZIPIG <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "ZIPIG", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.ZINBI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                             random = ~1|Individual, family = "ZINBI", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.ZANBI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                             random = ~1|Individual, family = "ZANBI", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.WARING <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                            random = ~1|Individual, family = "WARING", data = na.omit(dogs), control = con) #Fail
  
  Diversity.Dogs.ZIP <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                  random = ~1|Individual, family = "ZIP", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.ZAP <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "ZAP", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.PIG <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "PIG", data = na.omit(dogs), control = con)
  
  Diversity.Dogs.NBF <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "NBF", data = na.omit(dogs), control = con)
  
  }
AICs <- AIC(Diversity.Dogs.GEOM, Diversity.Dogs.DPO, Diversity.Dogs.NBI, Diversity.Dogs.GPO, Diversity.Dogs.ZAPIG, 
            Diversity.Dogs.ZIPIG, Diversity.Dogs.ZINBI, Diversity.Dogs.ZANBI, Diversity.Dogs.ZIP, Diversity.Dogs.ZAP,
            Diversity.Dogs.PIG, Diversity.Dogs.NBF)
write.csv(AICs, file="copypaste.csv") #For the copypasta

#Stage 2: Diagnostics via Plots
{
  plot(Diversity.Dogs.ZAP)
  wp(resid=resid(Diversity.Dogs.ZAP))
  
  plot(Diversity.Dogs.ZIP)
  wp(resid=resid(Diversity.Dogs.ZIP))
  
  plot(Diversity.Dogs.ZANBI)
  wp(resid=resid(Diversity.Dogs.ZANBI))
  
  plot(Diversity.Dogs.ZINBI)
  wp(resid=resid(Diversity.Dogs.ZINBI))
  
  plot(Diversity.Dogs.ZIPIG)
  wp(resid=resid(Diversity.Dogs.ZIPIG))
  
  plot(Diversity.Dogs.DPO)
  wp(resid=resid(Diversity.Dogs.DPO))
  
  plot(Diversity.Dogs.ZAPIG)
  wp(resid=resid(Diversity.Dogs.ZAPIG))
  
  plot(Diversity.Dogs.NBI)
  wp(resid=resid(Diversity.Dogs.NBI))
  
  plot(Diversity.Dogs.PIG)
  wp(resid=resid(Diversity.Dogs.PIG))

  plot(Diversity.Dogs.GPO)
  wp(resid=resid(Diversity.Dogs.GPO))
  
  plot(Diversity.Dogs.NBF)
  wp(resid=resid(Diversity.Dogs.NBF))
  
  plot(Diversity.Dogs.GEOM)
  wp(resid=resid(Diversity.Dogs.GEOM))
  }
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
  summary(Diversity.Dogs.ZAP)
  summary(Diversity.Dogs.ZIP)
  summary(Diversity.Dogs.ZANBI)
  summary(Diversity.Dogs.ZINBI)
  summary(Diversity.Dogs.ZIPIG)
  summary(Diversity.Dogs.DPO)
  summary(Diversity.Dogs.ZAPIG)
  summary(Diversity.Dogs.NBI)
  summary(Diversity.Dogs.PIG)
  summary(Diversity.Dogs.GPO)
  summary(Diversity.Dogs.NBF)
  summary(Diversity.Dogs.GEOM)
}

# Model Reduction & Validation --------------------------------------------

#Reduction of ZAP Model
{
  summary(Diversity.Dogs.ZAP)
  dropterm(Diversity.Dogs.ZAP, test = "Chisq")
  
  Diversity.Dogs.ZAP.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                 random = ~1|Individual, family = "ZAP", data = na.omit(dogs), control = con)
  summary(Diversity.Dogs.ZAP.2)
}

#Reduction of ZIP Model
{
  summary(Diversity.Dogs.ZIP)
  dropterm(Diversity.Dogs.ZIP, test = "Chisq")
  
  Diversity.Dogs.ZIP.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                              random = ~1|Individual, family = "ZIP", data = na.omit(dogs), control = con)
  summary(Diversity.Dogs.ZIP.2)
}

#Reduction of ZANBI Model
{
  summary(Diversity.Dogs.ZANBI)
  dropterm(Diversity.Dogs.ZANBI, test = "Chisq")
  
  Diversity.Dogs.ZANBI.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                 random = ~1|Individual, family = "ZANBI", data = na.omit(dogs), control = con)
  summary(Diversity.Dogs.ZANBI.2)
}

#Reduction of ZINBI Model
{
  summary(Diversity.Dogs.ZINBI)
  dropterm(Diversity.Dogs.ZINBI, test = "Chisq")
  
  Diversity.Dogs.ZINBI.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                   random = ~1|Individual, family = "ZINBI", data = na.omit(dogs), control = con)
  summary(Diversity.Dogs.ZINBI.2)
}

AICs <- AIC(Diversity.Dogs.ZAP, Diversity.Dogs.ZAP.2)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Diversity.Dogs.ZIP, Diversity.Dogs.ZIP.2)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Diversity.Dogs.ZANBI, Diversity.Dogs.ZANBI.2)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Diversity.Dogs.ZINBI, Diversity.Dogs.ZINBI.2)
write.csv(AICs, file="copypaste.csv")

# Plots -------------------------------------------------------------------

#Setting up the plot area
par(mar = c(3.5,3.5,2,0.15), #Defining the inner margins (Bottom, Left, Top, Right)
    oma = c(0.2,0.2,0,0), #Setting outer margins (same order as above)
    mgp = c (2.25,1,0), #Setting distance of labels from axis
    bg = NA) #Setting background colour to transparent

plot(Motor.Diversity ~ Persistence, data = dogs,
     main = "Motor Diversity vs. Persistence (Dogs)",
     xlab="Persistence (sec)", ylab="Number of manipulative behaviours shown")

#Adding a red coloured trend line
abline(lm(Motor.Diversity ~ Persistence, 
          data = dogs), col="red")