# Preparation -------------------------------------------------------------

##Load the required packages and read data in
library(gamlss)
library(readr)
wolves <- read_csv("wolves.csv")

#Ensure that your fixed factors are set as factors in the dataset
{
  wolves$Object <- as.factor(wolves$Object)
  wolves$Manipulated <- as.factor(wolves$Manipulated)
  wolves$Approach.Posture <- as.factor(wolves$Approach.Posture)
}

#And then check the structures just to make sure
str(wolves)

# Main Distribution Checks ------------------------------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is discrete, use "counts" as the type.

Wolves.Diversity.Distribution <- fitDist(wolves$Motor.Diversity, type = "counts")

#Have a look at what the AIC values for all the distributions that worked are.
Wolves.Diversity.Distribution$fits

write.csv(Wolves.Diversity.Distribution$fits, file="copypaste.csv") #For the copypasta

#Now let's look at what the distributions and fits look like
{
  histDist(Motor.Diversity, "PO", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "DPO", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "NBI", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "GPO", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "PIG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "GPO", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZAP", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZIP", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZANBI", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZAPIG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "NBF", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "SI", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "DEL", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZINBI", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "SICHEL", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "BNB", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
  histDist(Motor.Diversity, "ZIPIG", density = TRUE, data = na.omit(wolves), ylim = c(0,0.3))
}

# Main model distribution selection & validation --------------------------
#Stage 1: Building models & checking AICs
{
  #Let's change the maximum number of model iterations so we don't run into convergence errors.
  con = gamlss.control(n.cyc = 1000)
  
  #Let's try running the model we want with the distributions that might work and compare.
  
  Diversity.Wolves.PO <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                 random = ~1|Individual, family = "PO", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.DPO <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                 random = ~1|Individual, family = "DPO", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.NBI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                 random = ~1|Individual, family = "NBI", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.GPO <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "GPO", data = na.omit(wolves), control = con) 
  
  Diversity.Wolves.PIG <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "PIG", data = na.omit(wolves), control = con) #Fail
 
  Diversity.Wolves.ZAP <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "ZAP", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.ZIP <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                               random = ~1|Individual, family = "ZIP", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.ZANBI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                 random = ~1|Individual, family = "ZANBI", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.ZAPIG <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                 random = ~1|Individual, family = "ZAPIG", data = na.omit(wolves), control = con) #Fail
  
  Diversity.Wolves.NBF <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                 random = ~1|Individual, family = "NBF", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.SI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                   random = ~1|Individual, family = "SI", data = na.omit(wolves), control = con) #Fail
  
  Diversity.Wolves.DEL <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                    random = ~1|Individual, family = "DEL", data = na.omit(wolves), control = con)
  
  Diversity.Wolves.ZINBI <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                random = ~1|Individual, family = "ZINBI", data = na.omit(wolves), control = con)

  Diversity.Wolves.SICHEL <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                   random = ~1|Individual, family = "SICHEL", data = na.omit(wolves), control = con) #Fail
  
  Diversity.Wolves.BNB <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                    random = ~1|Individual, family = "BNB", data = na.omit(wolves), control = con) #Fail
  
  Diversity.Wolves.ZIPIG <- gamlss(Motor.Diversity ~ Object*Persistence + Age,
                                    random = ~1|Individual, family = "ZIPIG", data = na.omit(wolves), control = con)
  }
AICs <- AIC(Diversity.Wolves.PO, Diversity.Wolves.DPO, Diversity.Wolves.NBI, Diversity.Wolves.GPO, Diversity.Wolves.ZAP,
            Diversity.Wolves.ZIP, Diversity.Wolves.ZANBI, Diversity.Wolves.NBF, Diversity.Wolves.DEL,
            Diversity.Wolves.ZINBI, Diversity.Wolves.ZIPIG)
write.csv(AICs, file="copypaste.csv") #For the copypasta

#Stage 2: Diagnostics via Plots
{
  plot(Diversity.Wolves.DPO)
  wp(resid=resid(Diversity.Wolves.DPO))
  
  plot(Diversity.Wolves.PO)
  wp(resid=resid(Diversity.Wolves.PO))
  
  plot(Diversity.Wolves.ZAP)
  wp(resid=resid(Diversity.Wolves.ZAP))
  
  plot(Diversity.Wolves.NBI)
  wp(resid=resid(Diversity.Wolves.NBI))
  
  plot(Diversity.Wolves.GPO)
  wp(resid=resid(Diversity.Wolves.GPO))
  
  plot(Diversity.Wolves.ZIP)
  wp(resid=resid(Diversity.Wolves.ZIP))
  
  plot(Diversity.Wolves.ZANBI)
  wp(resid=resid(Diversity.Wolves.ZANBI))
  
  plot(Diversity.Wolves.DEL)
  wp(resid=resid(Diversity.Wolves.DEL))
  
  plot(Diversity.Wolves.ZIPIG)
  wp(resid=resid(Diversity.Wolves.ZIPIG))
  
  plot(Diversity.Wolves.NBF)
  wp(resid=resid(Diversity.Wolves.NBF))
  
  plot(Diversity.Wolves.ZINBI)
  wp(resid=resid(Diversity.Wolves.ZINBI))

}
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
  summary(Diversity.Wolves.DPO)
  summary(Diversity.Wolves.PO)
  summary(Diversity.Wolves.ZAP)
  summary(Diversity.Wolves.NBI)
  summary(Diversity.Wolves.GPO)
  summary(Diversity.Wolves.ZIP)
  summary(Diversity.Wolves.ZANBI)
  summary(Diversity.Wolves.DEL)
  summary(Diversity.Wolves.ZIPIG)
  summary(Diversity.Wolves.NBF)
  summary(Diversity.Wolves.ZINBI)
}

# Model Reduction & Validation --------------------------------------------

#Reduction of PO Model
{
  summary(Diversity.Wolves.PO)
  dropterm(Diversity.Wolves.PO, test = "Chisq")
  
  Diversity.Wolves.PO.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                 random = ~1|Individual, family = "PO", data = na.omit(wolves), control = con)
  summary(Diversity.Wolves.PO.2)
}

#Reduction of ZAP Model
{
  summary(Diversity.Wolves.ZAP)
  dropterm(Diversity.Wolves.ZAP, test = "Chisq")
  
  Diversity.Wolves.ZAP.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                 random = ~1|Individual, family = "ZAP", data = na.omit(wolves), control = con)
  summary(Diversity.Wolves.ZAP.2)
}

#Reduction of NBI Model
{
  summary(Diversity.Wolves.NBI)
  dropterm(Diversity.Wolves.NBI, test = "Chisq")
  
  Diversity.Wolves.NBI.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                   random = ~1|Individual, family = "NBI", data = na.omit(wolves), control = con)
  summary(Diversity.Wolves.NBI.2)
}

#Reduction of GPO Model
{
  summary(Diversity.Wolves.GPO)
  dropterm(Diversity.Wolves.GPO, test = "Chisq")
  
  Diversity.Wolves.GPO.2 <- gamlss(Motor.Diversity ~ Object + Persistence + Age,
                                   random = ~1|Individual, family = "GPO", data = na.omit(wolves), control = con)
  summary(Diversity.Wolves.GPO.2)
}

AICs <- AIC(Diversity.Wolves.PO, Diversity.Wolves.PO.2)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Diversity.Wolves.ZAP, Diversity.Wolves.ZAP.2)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Diversity.Wolves.NBI, Diversity.Wolves.NBI.2)
write.csv(AICs, file="copypaste.csv")

AICs <- AIC(Diversity.Wolves.GPO, Diversity.Wolves.GPO.2)
write.csv(AICs, file="copypaste.csv")

plot(Diversity.Wolves.PO.3)
wp(resid=resid(Diversity.Wolves.PO.3))

# Plots -------------------------------------------------------------------

#Setting up the plot area
par(mar = c(3.5,3.5,2,0.15), #Defining the inner margins (Bottom, Left, Top, Right)
    oma = c(0.2,0.2,0,0), #Setting outer margins (same order as above)
    mgp = c (2.25,1,0), #Setting distance of labels from axis
    bg = NA) #Setting background colour to transparent

plot(Motor.Diversity ~ Persistence, data = wolves,
     main = "Motor Diversity vs. Persistence (Wolves)",
     xlab="Persistence (sec)", ylab="Number of manipulative behaviours shown")

#Adding a red coloured trend line
abline(lm(Motor.Diversity ~ Persistence, 
          data = wolves), col="red")
