# Preparation -------------------------------------------------------------

##Load the required packages and read the data in
library(gamlss)

library(readr)
consistency <- read_csv("consistency.csv")

#Ensure that factors are set as such in the dataset
{
  consistency$Species <- as.factor(consistency$Species)
  plot$Species <- as.factor(plot$Species)
  plot$Aspect <- as.factor(plot$Aspect)
}

#And then check the structures just to make sure
str(consistency)



# Persistence Consistency Distribution Checks -----------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is continuous and ranges from 0 and 1, use "real0to1" as the type.

Persistence.Consistency.Distribution <- fitDist(consistency$persistence, type = "real0to1")

#Have a look at what the AIC values for all the distributions that worked are.
Persistence.Consistency.Distribution$fit

write.csv(Persistence.Consistency.Distribution$fit, file="copypaste.csv") #For the copypasta

#Let's look at what the distributions and fits look like
{
  histDist(persistence, "LOGITNO", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "GB1", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BE", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BEo", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BEINF0", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BEOI", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BEZI", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BEINF1", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "SIMPLEX", density = TRUE, data = na.omit(consistency))
  histDist(persistence, "BEINF", density = TRUE, data = na.omit(consistency))
}


# Persistence Consistency Model distribution selection & validation -------

#Stage 1: Building models & checking AICs
{
  #Let's change the maximum number of model iterations so we don't run into convergence errors.
  con = gamlss.control(n.cyc = 1000)
  
  #Let's try running the model we want with the distributions that might work and compare them.
  
  Persistence.Consistency.LOGITNO <- gamlss(persistence ~ Species,
                                family = "LOGITNO", data = na.omit(Consistency), control = con)
  
  Persistence.Consistency.GB1 <- gamlss(persistence ~ Species,
                                family = "GB1", data = na.omit(Consistency), control = con)
  
  Persistence.Consistency.BE <- gamlss(persistence ~ Species,
                            family = "BE", data = na.omit(Consistency), control = con)
  
  Persistence.Consistency.BEo <- gamlss(persistence ~ Species,
                            family = "BEo", data = na.omit(Consistency), control = con)
  
  Persistence.Consistency.SIMPLEX <- gamlss(persistence ~ Species,
                               family = "SIMPLEX", data = na.omit(Consistency), control = con)
  }
AICs <- AIC(Persistence.Consistency.LOGITNO, Persistence.Consistency.GB1, Persistence.Consistency.BE,
            Persistence.Consistency.BEo, Persistence.Consistency.SIMPLEX)
write.csv(AICs, file="copypaste.csv") #For the copypasta

#Stage 2: Diagnostics via Plots
{
  plot(Persistence.Consistency.LOGITNO)
  wp(resid=resid(Persistence.Consistency.LOGITNO))
  
  plot(Persistence.Consistency.GB1)
  wp(resid=resid(Persistence.Consistency.GB1))
  
  plot(Persistence.Consistency.BE)
  wp(resid=resid(Persistence.Consistency.BE))
  
  plot(Persistence.Consistency.BEo)
  wp(resid=resid(Persistence.Consistency.BEo))
  
  plot(Persistence.Consistency.SIMPLEX)
  wp(resid=resid(Persistence.Consistency.SIMPLEX))

}
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
  summary(Persistence.Consistency.GB1)
  summary(Persistence.Consistency.LOGITNO)
}


# Latency Consistency Distribution Checks -----------------------------

#Use fitDistr() to check which distributions from the GAMLSS family work for the data
#Data is continuous and ranges from 0 and 1, use "real0to1" as the type.

Latency.Consistency.Distribution <- fitDist(consistency$latency, type = "real0to1")

#Have a look at what the AIC values for all the distributions that worked are.
Latency.Consistency.Distribution$fit

write.csv(Latency.Consistency.Distribution$fit, file="copypaste.csv") #For the copypasta

#Now let's look at what the distributions and fits look like
{
  histDist(latency, "SIMPLEX", density = TRUE, data = na.omit(consistency))
  histDist(latency, "LOGITNO", density = TRUE, data = na.omit(consistency))
  histDist(latency, "GB1", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BEo", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BE", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BEINF0", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BEINF1", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BEOI", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BEZI", density = TRUE, data = na.omit(consistency))
  histDist(latency, "BEINF", density = TRUE, data = na.omit(consistency))
}


# Latency Consistency Model distribution selection & validation -------

#Stage 1: Building models & checking AICs
{
  #Let's change the maximum number of model iterations so we don't run into convergence errors.
  con = gamlss.control(n.cyc = 1000)
  
  #Let's try running the model we want with the distributions that might work and select the best fit.
  
  Latency.Consistency.SIMPLEX <- gamlss(latency ~ Species,
                                            family = "SIMPLEX", data = na.omit(consistency), control = con)
  
  Latency.Consistency.LOGITNO <- gamlss(latency ~ Species,
                                        family = "LOGITNO", data = na.omit(consistency), control = con)
  
  Latency.Consistency.BEo <- gamlss(latency ~ Species,
                                       family = "BEo", data = na.omit(consistency), control = con)
  
  Latency.Consistency.BE <- gamlss(latency ~ Species,
                                        family = "BE", data = na.omit(consistency), control = con)
}
AICs <- AIC(Latency.Consistency.SIMPLEX, Latency.Consistency.LOGITNO, Latency.Consistency.BEo,Latency.Consistency.BE)
write.csv(AICs, file="copypaste.csv") #For the copypasta

#Stage 2: Diagnostics via Plots
{
  plot(Latency.Consistency.SIMPLEX)
  wp(resid=resid(Latency.Consistency.SIMPLEX)) 
  
  plot(Latency.Consistency.LOGITNO)
  wp(resid=resid(Latency.Consistency.LOGITNO))
  
  plot(Latency.Consistency.BEo)
  wp(resid=resid(Latency.Consistency.BEo))

  plot(Latency.Consistency.BE)
  wp(resid=resid(Latency.Consistency.BE))
  
}
#Stage 3: Compare models that look the best, and a few more. Results should be similar
{
  summary(Latency.Consistency.SIMPLEX)
  summary(Latency.Consistency.LOGITNO)
  summary(Latency.Consistency.BEo)
  summary(Latency.Consistency.BE)
}

# Plots -------------------------------------------------------------------
#Run this code one section at a time.
#Setting up the plot area 
{
par(mar = c(3.5,3.5,2,0.15), #Defining the inner margins (Bottom, Left, Top, Right)
    oma = c(0.1,0.1,0,0), #Setting outer margins (same order as above)
    mgp = c (2,1,0), #Setting distance of labels from axis
    bg = NA) #Setting background colour to transparent
}

#Setting up a function to draw Significance lines
Significance.Line <- function() {#what the function does is specified in here
  lines(c(x1,x2), c(y,y)) #Draw a line between the two x coordinates the height of the y coordinate 
  lines(c(x1,x1), c(y,y-offset)) #Draw a line at the first x coordinate between y with the length "offset"
  lines(c(x2,x2), c(y,y-offset)) #Draw a line at the second x coordinate between y with the length "offset"
  text(((x1+x2)/2),(y+t1.offset),#Place text between first and second x coordiantes and "t1.offset" above line
       line.text1, cex = text1.size, color = text1.colour) #Use the text specified above, with the magnification & colour specified above
  text(((x1+x2)/2),(y-t2.offset),#Place text between first and second x coordiantes and "t2.offset" below line
       line.text2, cex = text2.size, color = text2.colour) #Use the text specified above, with the magnification & colour specified above
}

#Drawing the boxplot
{
at.x <- c(0.75,1.75,3,4) #Where you want the boxes to be drawn

boxplot(`Consistency Score` ~ Species*Aspect, data = plot,
        main = "Intra-individual Consistency in Problem-Solving Behaviour",
        xaxt = "n", ylab = "Consistency Score", #Supressing the normal X Axis & Adding a Y Label
        ylim = c(0.04,1.08),
        col = c("#DEB887", "#DCDCDC", "#CCA983", "#BABABA"), #Colours for the bars
        at = at.x) #Specifying where each box should be placed
}

#Setting up coordinates for the Persistence Significance Line
{
  y <- 1.06 #The height at which you want the line
  offset<- 0.02 #How long you want the ticks to be and how far above the line the * should be
  t1.offset <- 0.025 #How far above the line text 1 should be
  t2.offset <- 0.02 #How far below the line text 2 should be
  x1 <- at.x[1] #Specify the X coordinate of the first tick
  x2 <- at.x[2] #Specify the X coodrinate of the second tick
  line.text1 <- "P = 0.031" #What you want the text above the line to say
  text1.size <- 0.8 #The factor by which the text should be magnified
  text1.colour <- "black"
  line.text2 <- "GAMLSS, t = -2.31" #What you want the text below the line to say
  text2.size <- 0.7 #The factor by which the text should be magnified
  text2.colour <- "black"
  line.type <- 1
}

Significance.Line()

#Setting up coordinates for the Latency Significance Line
{
  y <- 1.06 #The height at which you want the line
  offset<- 0.02 #How long you want the ticks to be and how far above the line the * should be
  t1.offset <- 0.025 #How far above the line text 1 should be
  t2.offset <- 0.02 #How far below the line text 2 should be
  x1 <- at.x[3] #Specify the X coordinate of the first tick
  x2 <- at.x[4] #Specify the X coodrinate of the second tick
  line.text1 <- "P = 0.02" #What you want the text above the line to say
  text1.size <- 0.8 #The factor by which the text should be magnified
  text1.colour <- "black"
  line.text2 <- "GAMLSS, t = -2.62" #What you want the text below the line to say
  text2.size <- 0.7 #The factor by which the text should be magnified
  text2.colour <- "black"
  line.type <- 1
}

Significance.Line()

#Adding an "aftermarket" X axis
{
axis(1,
     at=at.x, #Specifying positions of the labels
     labels=c('Dogs', 'Wolves','Dogs', 'Wolves'), #Specifying what the labels should be called
     cex.axis = 1 #Specifying font size
     )
}

#Adding more axis labels
{
mtext(expression(bold("Persistence")), side = 1, #specifying the text and the axis below which it should be
      at=((at.x[1]+at.x[2])/2), #Specifying that the text should be between the first and second X axis tick
      line = 2.2) #Specifying how far below the plot the text should be

mtext(expression(bold("Contact Latency")), side = 1, #specifying the text and the axis below which it should be
      at=((at.x[3]+at.x[4])/2), #Specifying that the text should be between the third and fourth X axis tick
      line = 2.4) #Specifying how far below the plot the text should be
}